# How to demo the quadcopter

Follow this How-To to get the quadcopter up and running in Coover 3050. 

**Table of Contents**

[[_TOC_]]

## Setup Infrared Camera System

1. To start up the camera system, log into the camera system computer (co3050-07) with the following username and password:

    username: `camera` <br />
    password: `camera`

2. Once the OS is done loading, start up the program "Tracking Tools from the desktop".
3. From the startup window, choose "Open existing project"
4. From `D:\TrackingToolsData\FromLaptop` choose "TrackingToolsProject 2017-04-24 3.28pm" in the "Optitrack_Configuration" folder
6. Then go to File -> Open and choose "Microcart.tra" in the same folder
  - This should create a "UAV" under "Trackables" in the Project Explorer on the left side of the screen
7. Now you should be able to move the quadcopter trackable around in the tracking area, and see it update in real-time on the screen.

## Setup Ground Station
On the ground station computer (Co3050-microcart), log in with the following credentials. 

username: `ucart`<br>
password: `microcart`

Navigate to the ground station folder in a Terminal. 
```bash
$ cdsenior
BackEnd  Cli  logs  Makefile  obj  README.md  src  ucart.socket (or something like that)
```

If this is the first time using the ground station after cloning, you need to make VRPN.
From the `groundStation` folder:
```bash
make vrpn
```

To make the actual ground station program, e.g. if there have been any changes, run `make` from the `groundStation` folder.

## Setup Transmitter
The RC transmitter is used to manually control the quad.
1. Ensure the transmitter has the following state before turning it on:
  - "Gear" is set to 0
  - "Flap" is set to 1
  - Throttle is set to the lowest position
2. Turn on the transmitter.

## Copy Boot Image
To obtain an SD card image, navigate to the desired tag in GitLab (`team_17-16_demo`) and download the desired boot image. Copy it to an SD card, and rename it to `BOOT.bin`, which is the default filename for the Zybo to boot from.

## Setup Quadcopter
First, insert a fully charged battery with a monitor connected. The best policy is to always keep a battery monitor plugged in to prevent the battery from discharging too far.


1. Make sure the connection to the motors (red Deans connector) from the main power line is **disconnected**.
2. Insert the Li-Po battery into the holder beneath the quad, and plug it into the quad. See the image below to know how far back to place it.
![battery_placement](images/battery_placement.jpg)
3. Turn on the Zybo Board using the switch.
    1. The "PGOOD" Light should turn red.
    2. After the program has been completely loaded, the green DONE LED should turn on.
    3. *NOTE: The I<sup>2</sup>C devices do not get turned off when the Zybo switch is turned off, so to reboot, it is necessary to completely disconnect the battery, in addition to turning off the Zybo board switch.*
  ![image](/uploads/3aa1363e9f75982f259c2631bf9bcb8f/image.png)
4. Ensure the quad and transmitter have connected successfully.
    * The RC transmitter should have GAUI 330X selected and displayed on the screen. With the quad and transmitter on, the unit on the quad labeled Spektrum AR610 should have a blinking orange light or solid orange light (We don't know the difference, but the both seem to work?). If this is not blinking or solid, try restarting the quad and transmitter with the transmitter closer to the quad. 
  ![image](/uploads/f08672919265c5ff0017d28c1ba97770/image.png)
  ![image](/uploads/1a10172835c079f41395638d871f98e1/image.png)

5. Plug connect the motors to the main power line.

## Start the Ground Station (CLI)
Execute the following on the ground station from the root of the ground station folder.

In one terminal, run the backend:
```bash
./GroundStation
```

## Start the Quad
1. Using the transmitter, flip the "Gear" switch to 1.
  1. You should see the green LED4 MIO7 turn on.
2. Start flying the quad. Below is a summary of how the manual controls work.
  ![image](/uploads/b9e51151c344cba8f42f6b1d21273f31/image.png)


